You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@openoffice.apache.org by pf...@apache.org on 2014/04/29 21:13:57 UTC

svn commit: r1591061 [2/6] - in /openoffice/trunk/main/qadevOOo: runner/base/ runner/basicrunner/ runner/basicrunner/basichelper/ runner/complexlib/ runner/convwatch/ runner/graphical/ runner/helper/ runner/lib/ runner/org/openoffice/ runner/share/ run...

Modified: openoffice/trunk/main/qadevOOo/tests/basic/ifc/lang/XInitialization/lang_XInitialization.xba
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/basic/ifc/lang/XInitialization/lang_XInitialization.xba?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/basic/ifc/lang/XInitialization/lang_XInitialization.xba (original)
+++ openoffice/trunk/main/qadevOOo/tests/basic/ifc/lang/XInitialization/lang_XInitialization.xba Tue Apr 29 19:13:51 2014
@@ -37,7 +37,7 @@ option explicit
 
 '     - Global aInitArgs() As Variant
 '       Global aNoInit() As Variant [optional]
-'       if the variable defined as Array the method initialize() isnt called.
+'       if the variable defined as Array the method initialize() isn't called.
 
 '*************************************************************************
 

Modified: openoffice/trunk/main/qadevOOo/tests/basic/ifc/sdbc/XCloseable/sdbc_XCloseable.xba
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/basic/ifc/sdbc/XCloseable/sdbc_XCloseable.xba?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/basic/ifc/sdbc/XCloseable/sdbc_XCloseable.xba (original)
+++ openoffice/trunk/main/qadevOOo/tests/basic/ifc/sdbc/XCloseable/sdbc_XCloseable.xba Tue Apr 29 19:13:51 2014
@@ -67,7 +67,7 @@ ErrHndl:
     resume next
     
 ExpectErr:
-    Out.Log("Proper exception occured")
+    Out.Log("Proper exception occurred")
     bEx = true
     resume next
 End Sub

Modified: openoffice/trunk/main/qadevOOo/tests/basic/ifc/sdbcx/XRowLocate/sdbcx_XRowLocate.xba
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/basic/ifc/sdbcx/XRowLocate/sdbcx_XRowLocate.xba?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/basic/ifc/sdbcx/XRowLocate/sdbcx_XRowLocate.xba (original)
+++ openoffice/trunk/main/qadevOOo/tests/basic/ifc/sdbcx/XRowLocate/sdbcx_XRowLocate.xba Tue Apr 29 19:13:51 2014
@@ -63,14 +63,14 @@ On Error Goto ErrHndl
     cDscr2 = oObj.getString(1)
     Out.Log("Now on " + cDscr2)
     oObj.moveToBookmark(oBM1)
-    Out.Log("After movment on " + oObj.getString(1))
+    Out.Log("After movement on " + oObj.getString(1))
     bOK = bOK AND oObj.getString(1) = cDscr1
     Test.MethodTested("moveToBookmark()", bOK)
 
     Test.StartMethod("moveRelativeToBookmark()")
     bOK = true
     oObj.moveRelativeToBookmark(oBM1, 1)
-    Out.Log("After movment on " + oObj.getString(1))
+    Out.Log("After movement on " + oObj.getString(1))
     bOK = bOK AND oObj.getString(1) = cDscr2
     Test.MethodTested("moveRelativeToBookmark()", bOK)
 

Modified: openoffice/trunk/main/qadevOOo/tests/basic/ifc/text/XRelativeTextContentInsert/text_XRelativeTextContentInsert.xba
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/basic/ifc/text/XRelativeTextContentInsert/text_XRelativeTextContentInsert.xba?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/basic/ifc/text/XRelativeTextContentInsert/text_XRelativeTextContentInsert.xba (original)
+++ openoffice/trunk/main/qadevOOo/tests/basic/ifc/text/XRelativeTextContentInsert/text_XRelativeTextContentInsert.xba Tue Apr 29 19:13:51 2014
@@ -50,7 +50,7 @@ On Error Goto ErrHndl
     oCursor = oObj.createTextCursor()
     if (isNULL(oCursor)) then Out.Log("Can't create text cursor!")
 
-    Out.Log("First, mark all existant entries with 0")
+    Out.Log("First, mark all existent entries with 0")
 
     oEnum = oObj.createEnumeration()
     while (oEnum.hasMoreElements())

Modified: openoffice/trunk/main/qadevOOo/tests/basic/ifc/text/XTextColumns/text_XTextColumns.xba
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/basic/ifc/text/XTextColumns/text_XTextColumns.xba?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/basic/ifc/text/XTextColumns/text_XTextColumns.xba (original)
+++ openoffice/trunk/main/qadevOOo/tests/basic/ifc/text/XTextColumns/text_XTextColumns.xba Tue Apr 29 19:13:51 2014
@@ -84,7 +84,7 @@ On Error Goto ErrHndl
     ' initialize the pagestyle with the new values
     oPageStyle.TextColumns = oObj
 
-    ' check if ColumnsCount was set successfull
+    ' check if ColumnsCount was set successful
     Test.StartMethod("getColumnCount()")
     bOK = true
     bOK = bOK AND (nCount = oPageStyle.TextColumns.ColumnCount)

Modified: openoffice/trunk/main/qadevOOo/tests/basic/mod/dynamicloader.uno/Dynamic/dynamicloader_uno_Dynamic.xba
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/basic/mod/dynamicloader.uno/Dynamic/dynamicloader_uno_Dynamic.xba?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/basic/mod/dynamicloader.uno/Dynamic/dynamicloader_uno_Dynamic.xba (original)
+++ openoffice/trunk/main/qadevOOo/tests/basic/mod/dynamicloader.uno/Dynamic/dynamicloader_uno_Dynamic.xba Tue Apr 29 19:13:51 2014
@@ -32,7 +32,7 @@
 option explicit
 
 '*************************************************************************
-'!!! Doesnt currently work as service can't be instantiated.
+'!!! Doesn't currently work as service can't be instantiated.
 
 '*************************************************************************
 

Modified: openoffice/trunk/main/qadevOOo/tests/basic/mod/dynamicloader/Dynamic/dynamicloader_Dynamic.xba
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/basic/mod/dynamicloader/Dynamic/dynamicloader_Dynamic.xba?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/basic/mod/dynamicloader/Dynamic/dynamicloader_Dynamic.xba (original)
+++ openoffice/trunk/main/qadevOOo/tests/basic/mod/dynamicloader/Dynamic/dynamicloader_Dynamic.xba Tue Apr 29 19:13:51 2014
@@ -32,7 +32,7 @@
 option explicit
 
 '*************************************************************************
-'!!! Doesnt currently work as service can't be instantiated.
+'!!! Doesn't currently work as service can't be instantiated.
 
 '*************************************************************************
 

Modified: openoffice/trunk/main/qadevOOo/tests/basic/mod/sc/ScDDELinkObj/sc_ScDDELinkObj.xba
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/basic/mod/sc/ScDDELinkObj/sc_ScDDELinkObj.xba?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/basic/mod/sc/ScDDELinkObj/sc_ScDDELinkObj.xba (original)
+++ openoffice/trunk/main/qadevOOo/tests/basic/mod/sc/ScDDELinkObj/sc_ScDDELinkObj.xba Tue Apr 29 19:13:51 2014
@@ -60,7 +60,7 @@ On Error Goto ErrHndl
 
     DDEItem = "Sheet1.A1"
 
-    ' This construction of 2-way convertion of testdocs location 
+    ' This construction of 2-way conversion of testdocs location 
     ' should take place here, because there is unnecessary slash at the end of 
     ' cTestDocsDir.
     DDETopic = utils.URL2Path(utils.Path2URL(cTestDocsDir & "ScDDELinksObj.sdc"))

Modified: openoffice/trunk/main/qadevOOo/tests/basic/mod/sc/ScDDELinksObj/sc_ScDDELinksObj.xba
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/basic/mod/sc/ScDDELinksObj/sc_ScDDELinksObj.xba?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/basic/mod/sc/ScDDELinksObj/sc_ScDDELinksObj.xba (original)
+++ openoffice/trunk/main/qadevOOo/tests/basic/mod/sc/ScDDELinksObj/sc_ScDDELinksObj.xba Tue Apr 29 19:13:51 2014
@@ -51,7 +51,7 @@ On Error Goto ErrHndl
 
     oTestDoc = utils.loadTestDocument("ScDDELinksObj.sdc")
     
-    ' This construction of 2-way convertion of testdocs location 
+    ' This construction of 2-way conversion of testdocs location 
     ' should take place here, because there is unnecessary slash at the end of 
     ' cTestDocsDir.
     testDoc = utils.URL2Path(utils.Path2URL(cTestDocsDir & "ScDDELinksObj.sdc"))

Modified: openoffice/trunk/main/qadevOOo/tests/basic/mod/sc/ScIndexEnumeration_DDELinksEnumeration/sc_ScIndexEnumeration_DDELinksEnumeration.xba
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/basic/mod/sc/ScIndexEnumeration_DDELinksEnumeration/sc_ScIndexEnumeration_DDELinksEnumeration.xba?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/basic/mod/sc/ScIndexEnumeration_DDELinksEnumeration/sc_ScIndexEnumeration_DDELinksEnumeration.xba (original)
+++ openoffice/trunk/main/qadevOOo/tests/basic/mod/sc/ScIndexEnumeration_DDELinksEnumeration/sc_ScIndexEnumeration_DDELinksEnumeration.xba Tue Apr 29 19:13:51 2014
@@ -49,7 +49,7 @@ On Error Goto ErrHndl
 
     oTestDoc = utils.loadTestDocument("ScDDELinksObj.sdc")
     
-    ' This construction of 2-way convertion of testdocs location 
+    ' This construction of 2-way conversion of testdocs location 
     ' should take place here, because there is unnecessary slash at the end of 
     ' cTestDocsDir.
     testDoc = utils.URL2Path(utils.Path2URL(cTestDocsDir & "ScDDELinksObj.sdc"))

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/accessibility/_XAccessibleComponent.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/accessibility/_XAccessibleComponent.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/accessibility/_XAccessibleComponent.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/accessibility/_XAccessibleComponent.java Tue Apr 29 19:13:51 2014
@@ -495,7 +495,7 @@ public class _XAccessibleComponent exten
     /**
      * Just calls the method. <p>
      *
-     * Has <b> OK </b> status if no runtime exceptions occured.
+     * Has <b> OK </b> status if no runtime exceptions occurred.
      */
     public void _grabFocus() {
         boolean result = true;
@@ -509,7 +509,7 @@ public class _XAccessibleComponent exten
      * component which support <code>XAccessibleComponent</code>.
      *
      * @return The array of children. Empty array returned if
-     * such children were not found or some error occured.
+     * such children were not found or some error occurred.
      */
     private XAccessibleComponent[] getChildrenComponents() {
         XAccessible xAcc = (XAccessible) UnoRuntime.queryInterface(
@@ -555,7 +555,7 @@ public class _XAccessibleComponent exten
      * <code>XAccessibleComponent</code>.
      *
      * @return The parent or <code>null</code> if the component
-     * has no parent or some errors occured.
+     * has no parent or some errors occurred.
      */
     private XAccessibleComponent getParentComponent() {
         XAccessible xAcc = (XAccessible) UnoRuntime.queryInterface(

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XButton.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XButton.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XButton.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XButton.java Tue Apr 29 19:13:51 2014
@@ -87,7 +87,7 @@ public class _XButton extends MultiMetho
 
     /**
     * Just sets some text for label. <p>
-    * Has <b> OK </b> status if no runtime exceptions occured
+    * Has <b> OK </b> status if no runtime exceptions occurred
     */
     public void _setLabel() {
 
@@ -99,7 +99,7 @@ public class _XButton extends MultiMetho
 
     /**
     * Just sets some command for button. <p>
-    * Has <b> OK </b> status if no runtime exceptions occured
+    * Has <b> OK </b> status if no runtime exceptions occurred
     */
     public void _setActionCommand() {
 

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XComboBox.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XComboBox.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XComboBox.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XComboBox.java Tue Apr 29 19:13:51 2014
@@ -251,7 +251,7 @@ public class _XComboBox extends MultiMet
 
 	/**
 	* Gets line count and stores it. <p>
-	* Has <b>OK</b> status if no runtime exceptions occured.
+	* Has <b>OK</b> status if no runtime exceptions occurred.
 	*/
 	public void _getDropDownLineCount() {
 

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XCurrencyField.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XCurrencyField.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XCurrencyField.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XCurrencyField.java Tue Apr 29 19:13:51 2014
@@ -81,7 +81,7 @@ public class _XCurrencyField extends Mul
 
 	/**
 	* Just calls the method and stores value returned. <p>
-	* Has <b>OK</b> status if no runtime exceptions occured.
+	* Has <b>OK</b> status if no runtime exceptions occurred.
 	*/
 	public void _getValue() {
 		val = oObj.getValue();
@@ -107,7 +107,7 @@ public class _XCurrencyField extends Mul
 
 	/**
 	* Just calls the method and stores value returned. <p>
-	* Has <b>OK</b> status if no runtime exceptions occured.
+	* Has <b>OK</b> status if no runtime exceptions occurred.
 	*/
 	public void _getMin() {
 
@@ -137,7 +137,7 @@ public class _XCurrencyField extends Mul
 
 	/**
 	* Just calls the method and stores value returned. <p>
-	* Has <b>OK</b> status if no runtime exceptions occured.
+	* Has <b>OK</b> status if no runtime exceptions occurred.
 	*/
 	public void _getMax() {
 
@@ -168,7 +168,7 @@ public class _XCurrencyField extends Mul
 
 	/**
 	* Just calls the method and stores value returned. <p>
-	* Has <b>OK</b> status if no runtime exceptions occured.
+	* Has <b>OK</b> status if no runtime exceptions occurred.
 	*/
 	public void _getFirst() {
 
@@ -200,7 +200,7 @@ public class _XCurrencyField extends Mul
 
 	/**
 	* Just calls the method and stores value returned. <p>
-	* Has <b>OK</b> status if no runtime exceptions occured.
+	* Has <b>OK</b> status if no runtime exceptions occurred.
 	*/
 	public void _getLast() {
 
@@ -230,7 +230,7 @@ public class _XCurrencyField extends Mul
 
 	/**
 	* Just calls the method and stores value returned. <p>
-	* Has <b>OK</b> status if no runtime exceptions occured.
+	* Has <b>OK</b> status if no runtime exceptions occurred.
 	*/
 	public void _getSpinSize() {
 
@@ -262,7 +262,7 @@ public class _XCurrencyField extends Mul
 
 	/**
 	* Just calls the method and stores value returned. <p>
-	* Has <b>OK</b> status if no runtime exceptions occured.
+	* Has <b>OK</b> status if no runtime exceptions occurred.
 	*/
 	public void _getDecimalDigits() {
 
@@ -292,7 +292,7 @@ public class _XCurrencyField extends Mul
 
 	/**
 	* Just calls the method and stores value returned. <p>
-	* Has <b>OK</b> status if no runtime exceptions occured.
+	* Has <b>OK</b> status if no runtime exceptions occurred.
 	*/
 	public void _isStrictFormat() {
 

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XDateField.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XDateField.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XDateField.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XDateField.java Tue Apr 29 19:13:51 2014
@@ -84,7 +84,7 @@ public class _XDateField extends MultiMe
 
     /**
     * Gets the current value. <p>
-    * Has <b> OK </b> status if no runtime exceptions occured
+    * Has <b> OK </b> status if no runtime exceptions occurred
     */
     public void _getDate() {
 
@@ -114,7 +114,7 @@ public class _XDateField extends MultiMe
 
     /**
     * Gets the current value. <p>
-    * Has <b> OK </b> status if no runtime exceptions occured
+    * Has <b> OK </b> status if no runtime exceptions occurred
     */
     public void _getMin() {
 
@@ -144,7 +144,7 @@ public class _XDateField extends MultiMe
 
     /**
     * Gets the current value. <p>
-    * Has <b> OK </b> status if no runtime exceptions occured
+    * Has <b> OK </b> status if no runtime exceptions occurred
     */
     public void _getMax() {
 
@@ -178,7 +178,7 @@ public class _XDateField extends MultiMe
 
     /**
     * Gets the current value. <p>
-    * Has <b> OK </b> status if no runtime exceptions occured
+    * Has <b> OK </b> status if no runtime exceptions occurred
     */
     public void _getFirst() {
 
@@ -214,7 +214,7 @@ public class _XDateField extends MultiMe
 
     /**
     * Gets the current value. <p>
-    * Has <b> OK </b> status if no runtime exceptions occured
+    * Has <b> OK </b> status if no runtime exceptions occurred
     */
     public void _getLast() {
 
@@ -228,7 +228,7 @@ public class _XDateField extends MultiMe
 
     /**
     * Sets the value to empty. <p>
-    * Has <b> OK </b> status if no runtime exceptions occured
+    * Has <b> OK </b> status if no runtime exceptions occurred
     * The following method tests are to be completed successfully before :
     * <ul>
     *  <li> <code> setTime </code> : value must be not empty </li>
@@ -286,7 +286,7 @@ public class _XDateField extends MultiMe
 
     /**
     * Gets strict state and stores it. <p>
-    * Has <b> OK </b> status if no runtime exceptions occured.
+    * Has <b> OK </b> status if no runtime exceptions occurred.
     */
     public void _isStrictFormat() {
 
@@ -322,7 +322,7 @@ public class _XDateField extends MultiMe
 
     /**
     * Gets long format state and stores it. <p>
-    * Has <b> OK </b> status if no runtime exceptions occured.
+    * Has <b> OK </b> status if no runtime exceptions occurred.
     */
     public void _isLongFormat() {
 

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XDialog.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XDialog.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XDialog.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XDialog.java Tue Apr 29 19:13:51 2014
@@ -89,7 +89,7 @@ public class _XDialog extends MultiMetho
     * As this call is blocking then the thread execution
     * must not be finished. <p>
     * Has <b>OK</b> status if thread wasn't finished and
-    * no exceptions occured.
+    * no exceptions occurred.
     */
     public void _execute() {
         boolean result = true ;

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XFixedText.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XFixedText.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XFixedText.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XFixedText.java Tue Apr 29 19:13:51 2014
@@ -67,7 +67,7 @@ public class _XFixedText extends MultiMe
 
     /**
     * Just calls the method and stores value returned. <p>
-    * Has <b>OK</b> status if no runtime exceptions occured.
+    * Has <b>OK</b> status if no runtime exceptions occurred.
     */
     public void _getText() {
 
@@ -101,7 +101,7 @@ public class _XFixedText extends MultiMe
 
     /**
     * Just calls the method and stores value returned. <p>
-    * Has <b>OK</b> status if no runtime exceptions occured.
+    * Has <b>OK</b> status if no runtime exceptions occurred.
     */
     public void _getAlignment() {
 

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XImageConsumer.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XImageConsumer.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XImageConsumer.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XImageConsumer.java Tue Apr 29 19:13:51 2014
@@ -48,7 +48,7 @@ public class _XImageConsumer extends Mul
 
     /**
     * Initialize the consumer with size 2x2. <p>
-    * Has <b> OK </b> status if no runtime exceptions occured
+    * Has <b> OK </b> status if no runtime exceptions occurred
     */
     public void _init() {
 
@@ -60,7 +60,7 @@ public class _XImageConsumer extends Mul
 
     /**
     * Sets color model. <p>
-    * Has <b> OK </b> status if no runtime exceptions occured
+    * Has <b> OK </b> status if no runtime exceptions occurred
     * The following method tests are to be completed successfully before :
     * <ul>
     *  <li> <code> init </code> </li>
@@ -79,7 +79,7 @@ public class _XImageConsumer extends Mul
 
     /**
     * Fill the picture with for pixels. <p>
-    * Has <b> OK </b> status if no runtime exceptions occured
+    * Has <b> OK </b> status if no runtime exceptions occurred
     * The following method tests are to be executed before :
     * <ul>
     *  <li> <code> setColorModel </code> </li>
@@ -97,7 +97,7 @@ public class _XImageConsumer extends Mul
 
     /**
     * Fill the picture with for pixels. <p>
-    * Has <b> OK </b> status if no runtime exceptions occured
+    * Has <b> OK </b> status if no runtime exceptions occurred
     * The following method tests are to be executed before :
     * <ul>
     *  <li> <code> setColorModel </code> </li>
@@ -114,7 +114,7 @@ public class _XImageConsumer extends Mul
 
     /**
     * Just calls the method. <p>
-    * Has <b> OK </b> status if no runtime exceptions occured
+    * Has <b> OK </b> status if no runtime exceptions occurred
     * The following method tests are to be completed successfully before :
     * <ul>
     *  <li> <code> init </code>  </li>

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XImageProducer.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XImageProducer.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XImageProducer.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XImageProducer.java Tue Apr 29 19:13:51 2014
@@ -106,7 +106,7 @@ public class _XImageProducer extends Mul
 
     /**
     * Adds a new consumer to producer. <p>
-    * Has <b> OK </b> status if no runtime exceptions occured
+    * Has <b> OK </b> status if no runtime exceptions occurred
     */
     public void _addConsumer() {
 
@@ -118,7 +118,7 @@ public class _XImageProducer extends Mul
 
     /**
     * Removes the consumer added before. <p>
-    * Has <b> OK </b> status if no runtime exceptions occured
+    * Has <b> OK </b> status if no runtime exceptions occurred
     * The following method tests are to be executed before :
     * <ul>
     *  <li> <code> startProduction </code>  </li>

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XListBox.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XListBox.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XListBox.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XListBox.java Tue Apr 29 19:13:51 2014
@@ -275,7 +275,7 @@ public class _XListBox extends MultiMeth
 
     /**
     * Gets line count and stores it. <p>
-    * Has <b>OK</b> status if no runtime exceptions occured.
+    * Has <b>OK</b> status if no runtime exceptions occurred.
     */
     public void _getDropDownLineCount() {
 
@@ -407,7 +407,7 @@ public class _XListBox extends MultiMeth
 
     /**
     * Unselects all items, then selects a single item. <p>
-    * Has <b> OK </b> status if no runtime exceptions occured
+    * Has <b> OK </b> status if no runtime exceptions occurred
     * The following method tests are to be completed successfully before :
     * <ul>
     *  <li> <code> addItems </code> : to have some items </li>
@@ -428,7 +428,7 @@ public class _XListBox extends MultiMeth
 
     /**
     * Just selects some items. <p>
-    * Has <b> OK </b> status if no runtime exceptions occured
+    * Has <b> OK </b> status if no runtime exceptions occurred
     * The following method tests are to be completed successfully before :
     * <ul>
     *  <li> <code> addItems </code> : to have some items </li>
@@ -446,7 +446,7 @@ public class _XListBox extends MultiMeth
 
     /**
     * Just selects an item. <p>
-    * Has <b> OK </b> status if no runtime exceptions occured
+    * Has <b> OK </b> status if no runtime exceptions occurred
     * The following method tests are to be completed successfully before :
     * <ul>
     *  <li> <code> addItems </code> : to have some items </li>
@@ -480,7 +480,7 @@ public class _XListBox extends MultiMeth
 
     /**
     * Sets multiple mode. <p>
-    * Has <b> OK </b> status if no runtime exceptions occured
+    * Has <b> OK </b> status if no runtime exceptions occurred
     */
     public void _setMultipleMode() {
 
@@ -492,7 +492,7 @@ public class _XListBox extends MultiMeth
 
     /**
     * Just calls the method to make visible third item. <p>
-    * Has <b> OK </b> status if no runtime exceptions occured.<p>
+    * Has <b> OK </b> status if no runtime exceptions occurred.<p>
     * The following method tests are to be completed successfully before :
     * <ul>
     *  <li> <code> addItems </code> </li>

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XNumericField.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XNumericField.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XNumericField.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XNumericField.java Tue Apr 29 19:13:51 2014
@@ -82,7 +82,7 @@ public class _XNumericField extends Mult
 
     /**
     * Just calls the method and stores value returned. <p>
-    * Has <b>OK</b> status if no runtime exceptions occured.
+    * Has <b>OK</b> status if no runtime exceptions occurred.
     */
     public void _getValue() {
         val = oObj.getValue() ;
@@ -108,7 +108,7 @@ public class _XNumericField extends Mult
 
     /**
     * Just calls the method and stores value returned. <p>
-    * Has <b>OK</b> status if no runtime exceptions occured.
+    * Has <b>OK</b> status if no runtime exceptions occurred.
     */
     public void _getMin() {
 
@@ -138,7 +138,7 @@ public class _XNumericField extends Mult
 
     /**
     * Just calls the method and stores value returned. <p>
-    * Has <b>OK</b> status if no runtime exceptions occured.
+    * Has <b>OK</b> status if no runtime exceptions occurred.
     */
     public void _getMax() {
 
@@ -169,7 +169,7 @@ public class _XNumericField extends Mult
 
     /**
     * Just calls the method and stores value returned. <p>
-    * Has <b>OK</b> status if no runtime exceptions occured.
+    * Has <b>OK</b> status if no runtime exceptions occurred.
     */
     public void _getFirst() {
 
@@ -201,7 +201,7 @@ public class _XNumericField extends Mult
 
     /**
     * Just calls the method and stores value returned. <p>
-    * Has <b>OK</b> status if no runtime exceptions occured.
+    * Has <b>OK</b> status if no runtime exceptions occurred.
     */
     public void _getLast() {
 
@@ -231,7 +231,7 @@ public class _XNumericField extends Mult
 
     /**
     * Just calls the method and stores value returned. <p>
-    * Has <b>OK</b> status if no runtime exceptions occured.
+    * Has <b>OK</b> status if no runtime exceptions occurred.
     */
     public void _getSpinSize() {
 
@@ -263,7 +263,7 @@ public class _XNumericField extends Mult
 
     /**
     * Just calls the method and stores value returned. <p>
-    * Has <b>OK</b> status if no runtime exceptions occured.
+    * Has <b>OK</b> status if no runtime exceptions occurred.
     */
     public void _getDecimalDigits() {
 
@@ -293,7 +293,7 @@ public class _XNumericField extends Mult
 
     /**
     * Just calls the method and stores value returned. <p>
-    * Has <b>OK</b> status if no runtime exceptions occured.
+    * Has <b>OK</b> status if no runtime exceptions occurred.
     */
     public void _isStrictFormat() {
 

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XPatternField.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XPatternField.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XPatternField.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XPatternField.java Tue Apr 29 19:13:51 2014
@@ -78,7 +78,7 @@ public class _XPatternField extends Mult
 
     /**
     * Gets masks and stores them. <p>
-    * Has <b> OK </b> status if no runtime exceptions occured.
+    * Has <b> OK </b> status if no runtime exceptions occurred.
     */
     public void _getMasks() {
 
@@ -127,7 +127,7 @@ public class _XPatternField extends Mult
 
     /**
     * Gets current string and stores it. <p>
-    * Has <b> OK </b> status if no runtime exceptions occured
+    * Has <b> OK </b> status if no runtime exceptions occurred
     */
     public void _getString() {
 
@@ -158,7 +158,7 @@ public class _XPatternField extends Mult
 
     /**
     * Gets the current strict state and stores it. <p>
-    * Has <b> OK </b> status if no runtime exceptions occured.
+    * Has <b> OK </b> status if no runtime exceptions occurred.
     */
     public void _isStrictFormat() {
 

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XRadioButton.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XRadioButton.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XRadioButton.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XRadioButton.java Tue Apr 29 19:13:51 2014
@@ -98,7 +98,7 @@ public class _XRadioButton extends Multi
 
     /**
     * Gets state and stores it. <p>
-    * Has <b> OK </b> status if no runtime exceptions occured
+    * Has <b> OK </b> status if no runtime exceptions occurred
     */
     public void _getState() {
 
@@ -133,7 +133,7 @@ public class _XRadioButton extends Multi
 
     /**
     * Just sets a new label. <p>
-    * Has <b> OK </b> status if no runtime exceptions occured
+    * Has <b> OK </b> status if no runtime exceptions occurred
     */
     public void _setLabel() {
 

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XSpinField.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XSpinField.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XSpinField.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XSpinField.java Tue Apr 29 19:13:51 2014
@@ -78,7 +78,7 @@ public class _XSpinField extends MultiMe
 
     /**
     * Just adds a listener. <p>
-    * Has <b>OK</b> status if no runtime exceptions occured.
+    * Has <b>OK</b> status if no runtime exceptions occurred.
     */
     public void _addSpinListener() {
         oObj.addSpinListener(listener) ;
@@ -189,7 +189,7 @@ public class _XSpinField extends MultiMe
 
     /**
     * Enables then disables repeating. <p>
-    * Has <b>OK</b> status if no runtime exceptions occured.
+    * Has <b>OK</b> status if no runtime exceptions occurred.
     */
     public void _enableRepeat() {
         oObj.enableRepeat(true) ;

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XTimeField.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XTimeField.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XTimeField.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XTimeField.java Tue Apr 29 19:13:51 2014
@@ -80,7 +80,7 @@ public class _XTimeField extends MultiMe
 
     /**
     * Gets the current value. <p>
-    * Has <b> OK </b> status if no runtime exceptions occured
+    * Has <b> OK </b> status if no runtime exceptions occurred
     */
     public void _getTime() {
 
@@ -110,7 +110,7 @@ public class _XTimeField extends MultiMe
 
     /**
     * Gets the current value. <p>
-    * Has <b> OK </b> status if no runtime exceptions occured
+    * Has <b> OK </b> status if no runtime exceptions occurred
     */
     public void _getMin() {
 
@@ -140,7 +140,7 @@ public class _XTimeField extends MultiMe
 
     /**
     * Gets the current value. <p>
-    * Has <b> OK </b> status if no runtime exceptions occured
+    * Has <b> OK </b> status if no runtime exceptions occurred
     */
     public void _getMax() {
 
@@ -174,7 +174,7 @@ public class _XTimeField extends MultiMe
 
     /**
     * Gets the current value. <p>
-    * Has <b> OK </b> status if no runtime exceptions occured
+    * Has <b> OK </b> status if no runtime exceptions occurred
     */
     public void _getFirst() {
 
@@ -210,7 +210,7 @@ public class _XTimeField extends MultiMe
 
     /**
     * Gets the current value. <p>
-    * Has <b> OK </b> status if no runtime exceptions occured
+    * Has <b> OK </b> status if no runtime exceptions occurred
     */
     public void _getLast() {
 
@@ -224,7 +224,7 @@ public class _XTimeField extends MultiMe
 
     /**
     * Sets the value to empty. <p>
-    * Has <b> OK </b> status if no runtime exceptions occured
+    * Has <b> OK </b> status if no runtime exceptions occurred
     * The following method tests are to be completed successfully before :
     * <ul>
     *  <li> <code> setTime </code> : value must be not empty </li>
@@ -277,7 +277,7 @@ public class _XTimeField extends MultiMe
 
     /**
     * Gets strict state and stores it. <p>
-    * Has <b> OK </b> status if no runtime exceptions occured.
+    * Has <b> OK </b> status if no runtime exceptions occurred.
     */
     public void _isStrictFormat() {
 

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XToolkit.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XToolkit.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XToolkit.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XToolkit.java Tue Apr 29 19:13:51 2014
@@ -89,7 +89,7 @@ public class _XToolkit extends MultiMeth
                 res = true;
             }
         } catch (com.sun.star.lang.IllegalArgumentException ex) {
-            log.println("Exception occured while checking 'createWindow':");
+            log.println("Exception occurred while checking 'createWindow':");
             ex.printStackTrace(log);
         }
         tRes.tested("createWindow()", res);
@@ -115,7 +115,7 @@ public class _XToolkit extends MultiMeth
                 res = true;
             }
         } catch (com.sun.star.lang.IllegalArgumentException ex) {
-            log.println("Exception occured while checking 'createWindows':");
+            log.println("Exception occurred while checking 'createWindows':");
             ex.printStackTrace(log);
         }
         tRes.tested("createWindows()", res);

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XTopWindow.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XTopWindow.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XTopWindow.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XTopWindow.java Tue Apr 29 19:13:51 2014
@@ -161,7 +161,7 @@ public class _XTopWindow extends MultiMe
 
     /**
     * Creates a simple menu bar and adds to the window. <p>
-    * Has <b>OK</b> status if no runtime exceptions occured.
+    * Has <b>OK</b> status if no runtime exceptions occurred.
     */
     public void _setMenuBar() {
         XMenuBar menu = null ;

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XUnoControlContainer.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XUnoControlContainer.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XUnoControlContainer.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XUnoControlContainer.java Tue Apr 29 19:13:51 2014
@@ -61,7 +61,7 @@ public class _XUnoControlContainer exten
         tabControl1 = (XTabController) tEnv.getObjRelation("TABCONTROL1");
         tabControl2 = (XTabController) tEnv.getObjRelation("TABCONTROL2");
         if ((tabControl1 == null) || (tabControl2 == null)){
-            log.println("ERROR: Needed object realtions 'TABCONTROL1' and "
+            log.println("ERROR: Needed object relations 'TABCONTROL1' and "
             + "'TABCONTROL2' are not found.");
         }
         TabControllers[0] = tabControl1;

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XUserInputInterception.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XUserInputInterception.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XUserInputInterception.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XUserInputInterception.java Tue Apr 29 19:13:51 2014
@@ -273,7 +273,7 @@ public class _XUserInputInterception ext
             return true;
         }
         /**
-         * This event does nothing usefull
+         * This event does nothing useful
          * @param oEvent refers to the object that fired the event.
          */
         public void disposing( EventObject oEvent ){
@@ -310,7 +310,7 @@ public class _XUserInputInterception ext
             return true;
         }
         /**
-         * This event does nothing usefull
+         * This event does nothing useful
          * @param oEvent refers to the object that fired the event.
          */
         public void disposing( EventObject oEvent ){
@@ -347,7 +347,7 @@ public class _XUserInputInterception ext
             return true;
         }
         /**
-         * This event does nothing usefull
+         * This event does nothing useful
          * @param oEvent refers to the object that fired the event.
          */
         public void disposing( EventObject oEvent ){
@@ -385,7 +385,7 @@ public class _XUserInputInterception ext
             return true;
         }
         /**
-         * This event does nothing usefull
+         * This event does nothing useful
          * @param oEvent refers to the object that fired the event.
          */
         public void disposing( EventObject oEvent ){
@@ -417,7 +417,7 @@ public class _XUserInputInterception ext
         
         /**
          * Creates an instacne of this class. The parameter <CODE>eType</CODE> represents
-         * the kind of event wich will be triggert at <CODE>run()</CODE>
+         * the kind of event which will be triggert at <CODE>run()</CODE>
          * @param model the model of a document
          * @param eType the kind of event which should be trigger
          */
@@ -428,7 +428,7 @@ public class _XUserInputInterception ext
         }
         
         /**
-         * Triggers the event wich is represented by <CODE>eventType</CODE>
+         * Triggers the event which is represented by <CODE>eventType</CODE>
          * The scenarios are:
          * <ul>
          *    <li>EventTest.EventTriggerType.MOUSE_KLICK_INTO_DOC

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XWindow.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XWindow.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XWindow.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/_XWindow.java Tue Apr 29 19:13:51 2014
@@ -202,13 +202,13 @@ public class _XWindow extends MultiMetho
     /**
     * Test calls the method. Then we check if listener's methods were called
     * when we move, resize, hide and show the window. The resizing is
-    * performed depending on 'XWindow.ControlShape' existance. If this
+    * performed depending on 'XWindow.ControlShape' existence. If this
     * relation exists then the size and position of container control
     * shape is changed, else the position and size of window itself is
     * chaged<p>
     *
     * Has <b> OK </b> status if methods of wListener were called when
-    * corresponding events occured. <p>
+    * corresponding events occurred. <p>
     *
     * The following method tests are to be executed before :
     * <ul>
@@ -352,7 +352,7 @@ public class _XWindow extends MultiMetho
     * Test calls the method. Then we change focus and check that listener's
     * methods were called. <p>
     * Has <b> OK </b> status if methods of fListener were called when
-    * corresponding events occured. <p>
+    * corresponding events occurred. <p>
     * The following method tests are to be completed successfully before :
     * <ul>
     *  <li> <code> setFocus() </code>: sets the focus to the window </li>

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/tree/_XMutableTreeNode.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/tree/_XMutableTreeNode.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/tree/_XMutableTreeNode.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/awt/tree/_XMutableTreeNode.java Tue Apr 29 19:13:51 2014
@@ -140,7 +140,7 @@ public class _XMutableTreeNode extends M
             log.println("ERROR: expected IndexOutOfBoundsException was not thrown => FAILED");
             bOK = false;
         } catch (com.sun.star.lang.IllegalArgumentException ex) {
-            log.println("ERROR: wrong IllegalArgumentException was thrown. Expeced is IndexOutOfBoundsException => FAILED");
+            log.println("ERROR: wrong IllegalArgumentException was thrown. Expected is IndexOutOfBoundsException => FAILED");
             bOK = false;
         } catch (com.sun.star.lang.IndexOutOfBoundsException ex) {
             log.println("Expected IndexOutOfBoundsException was thrown => OK");
@@ -177,7 +177,7 @@ public class _XMutableTreeNode extends M
         try {
             log.println("try to remove node at invalid index '-3'");
             oObj.removeChildByIndex(-3);
-            log.println("ERROR: expeced IndexOutOfBoundsException was not thrown => FAILED");
+            log.println("ERROR: expected IndexOutOfBoundsException was not thrown => FAILED");
             bOK = false;
         } catch (com.sun.star.lang.IndexOutOfBoundsException ex) {
             log.println("expected IndexOutOfBoundsException was thrown => OK");

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/beans/_XFastPropertySet.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/beans/_XFastPropertySet.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/beans/_XFastPropertySet.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/beans/_XFastPropertySet.java Tue Apr 29 19:13:51 2014
@@ -104,16 +104,16 @@ public class _XFastPropertySet extends M
                 oObj.setFastPropertyValue(handle, sValue);
                 sValue = oObj.getFastPropertyValue(handle);
             } catch (com.sun.star.beans.UnknownPropertyException e) {
-                log.println("Exception occured while trying to change property with handle = " + handle);
+                log.println("Exception occurred while trying to change property with handle = " + handle);
                 e.printStackTrace(log);
             } catch (com.sun.star.lang.WrappedTargetException e) {
-                log.println("Exception occured while trying to change property with handle = " + handle);
+                log.println("Exception occurred while trying to change property with handle = " + handle);
                 e.printStackTrace(log);
             } catch (com.sun.star.beans.PropertyVetoException e) {
-                log.println("Exception occured while trying to change property with handle = " + handle);
+                log.println("Exception occurred while trying to change property with handle = " + handle);
                 e.printStackTrace(log);
             }  catch (com.sun.star.lang.IllegalArgumentException e) {
-                log.println("Exception occured while trying to change property with handle = " + handle);
+                log.println("Exception occurred while trying to change property with handle = " + handle);
                 e.printStackTrace(log);
             }
 
@@ -143,12 +143,12 @@ public class _XFastPropertySet extends M
             oObj.getFastPropertyValue(handle);
             tRes.tested("getFastPropertyValue()",true);
         } catch (com.sun.star.beans.UnknownPropertyException e) {
-            log.println("Exception occured while trying to get property '"
+            log.println("Exception occurred while trying to get property '"
                 + handle +"'");
             e.printStackTrace(log);
             tRes.tested("getFastPropertyValue()",false);
         } catch (com.sun.star.lang.WrappedTargetException e) {
-            log.println("Exception occured while trying to get property '"
+            log.println("Exception occurred while trying to get property '"
                 + handle +"'");
             e.printStackTrace(log);
             tRes.tested("getFastPropertyValue()",false);

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/beans/_XMultiPropertySet.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/beans/_XMultiPropertySet.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/beans/_XMultiPropertySet.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/beans/_XMultiPropertySet.java Tue Apr 29 19:13:51 2014
@@ -194,15 +194,15 @@ public class _XMultiPropertySet extends 
                 result &= propertiesChanged ;
                 log.println(" ... done");
             } catch (com.sun.star.beans.PropertyVetoException e) {
-                log.println("Exception occured while trying to change "+
+                log.println("Exception occurred while trying to change "+
                     "property '"+testPropsNames[i] + "' :" + e);
                 e.printStackTrace(log);
             } catch (com.sun.star.lang.IllegalArgumentException e) {
-                log.println("Exception occured while trying to change "+
+                log.println("Exception occurred while trying to change "+
                     "property '"+testPropsNames[i] + "' :" + e);
                 e.printStackTrace(log);
             } catch (com.sun.star.lang.WrappedTargetException e) {
-                log.println("Exception occured while trying to change "+
+                log.println("Exception occurred while trying to change "+
                     "property '"+testPropsNames[i] + "' :" + e);
                 e.printStackTrace(log);
             } // end of try-catch
@@ -293,15 +293,15 @@ public class _XMultiPropertySet extends 
                 }
             }
         } catch (com.sun.star.beans.PropertyVetoException e) {
-            log.println("Exception occured while setting properties");
+            log.println("Exception occurred while setting properties");
             e.printStackTrace(log);
             bResult = false;
         } catch (com.sun.star.lang.IllegalArgumentException e) {
-            log.println("Exception occured while setting properties");
+            log.println("Exception occurred while setting properties");
             e.printStackTrace(log);
             bResult = false;
         } catch (com.sun.star.lang.WrappedTargetException e) {
-            log.println("Exception occured while setting properties");
+            log.println("Exception occurred while setting properties");
             e.printStackTrace(log);
             bResult = false;
         } // end of try-catch

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/beans/_XPropertySet.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/beans/_XPropertySet.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/beans/_XPropertyState.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/beans/_XPropertyState.java Tue Apr 29 19:13:51 2014
@@ -131,11 +131,11 @@ public class _XPropertyState extends Mul
                 log.println("Default property value is : '" + propDef + "'");
             } catch (com.sun.star.beans.UnknownPropertyException e) {
                 log.println("Exception " + e +
-                    "occured while getting Property default");
+                    "occurred while getting Property default");
                 result=false;
             } catch (com.sun.star.lang.WrappedTargetException e) {
                 log.println("Exception " + e +
-                    "occured while getting Property default");
+                    "occurred while getting Property default");
                 result=false;
             }
             tRes.tested("getPropertyDefault()", result);
@@ -163,7 +163,7 @@ public class _XPropertyState extends Mul
                 }
             } catch (com.sun.star.beans.UnknownPropertyException e) {
                 log.println("Exception " + e +
-                    "occured while getting Property state");
+                    "occurred while getting Property state");
                 result = false;
             }
             tRes.tested("getPropertyState()", result);
@@ -198,7 +198,7 @@ public class _XPropertyState extends Mul
                 }
             } catch (com.sun.star.beans.UnknownPropertyException e) {
                 log.println("Exception " + e +
-                    "occured while getting Property state");
+                    "occurred while getting Property state");
                 result = false;
             }
 
@@ -251,11 +251,11 @@ public class _XPropertyState extends Mul
                 }
             } catch (com.sun.star.beans.UnknownPropertyException e) {
                 log.println("Exception " + e +
-                    "occured while setting Property to default");
+                    "occurred while setting Property to default");
                 result=false;
             } catch (com.sun.star.lang.WrappedTargetException e) {
                 log.println("Exception " + e +
-                    "occured while testing property value");
+                    "occurred while testing property value");
                 result=false;
             }
 

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/bridge/_XBridgeFactory.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/bridge/_XBridgeFactory.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/bridge/_XBridgeFactory.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/bridge/_XBridgeFactory.java Tue Apr 29 19:13:51 2014
@@ -64,7 +64,7 @@ public class _XBridgeFactory extends Mul
     }
     /**
     * Calls <code>accept()</code> method in a separate thread.
-    * Then stores exception thrown by call if it occured, or
+    * Then stores exception thrown by call if it occurred, or
     * return value.
     */
     protected class AcceptorThread extends Thread {
@@ -73,7 +73,7 @@ public class _XBridgeFactory extends Mul
          */
         private XAcceptor acc = null ;
         /**
-        * If exception occured during method call it is
+        * If exception occurred during method call it is
         * stored in this field.
         */
         public Exception ex = null ;

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/connection/_XAcceptor.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/connection/_XAcceptor.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/container/_XChild.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/container/_XChild.java Tue Apr 29 19:13:51 2014
@@ -84,7 +84,7 @@ public class _XChild extends MultiMethod
             tRes.tested("setParent()",true);
         }
         catch (com.sun.star.lang.NoSupportException ex) {
-            log.println("Exception occured during setParent()");
+            log.println("Exception occurred during setParent()");
             ex.printStackTrace(log);
             tRes.tested("setParent()",false);
         }

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/container/_XContainer.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/container/_XContainer.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/container/_XContainer.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/container/_XContainer.java Tue Apr 29 19:13:51 2014
@@ -237,19 +237,19 @@ public class _XContainer extends MultiMe
             }
             NC.removeByName("XContainer_dummy");
         } catch (com.sun.star.lang.IllegalArgumentException ex) {
-            log.println("Exception occured ");
+            log.println("Exception occurred ");
             ex.printStackTrace(log);
             bResult = false;
         } catch (com.sun.star.lang.WrappedTargetException ex) {
-            log.println("Exception occured ");
+            log.println("Exception occurred ");
             ex.printStackTrace(log);
             bResult = false;
         } catch (com.sun.star.container.NoSuchElementException ex) {
-            log.println("Exception occured ");
+            log.println("Exception occurred ");
             ex.printStackTrace(log);
             bResult = false;
         } catch (com.sun.star.container.ElementExistException ex) {
-            log.println("Exception occured ");
+            log.println("Exception occurred ");
             ex.printStackTrace(log);
             bResult = false;
         }

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/container/_XContainerQuery.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/container/_XContainerQuery.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/container/_XContainerQuery.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/container/_XContainerQuery.java Tue Apr 29 19:13:51 2014
@@ -109,11 +109,11 @@ public class _XContainerQuery extends Mu
                     Object element = subSet.nextElement();
 
                     } catch (com.sun.star.container.NoSuchElementException e){
-                        log.println("Exception occured ");
+                        log.println("Exception occurred ");
                         e.printStackTrace(log);
                         bResult = false;
                     } catch (com.sun.star.lang.WrappedTargetException e){
-                        log.println("Exception occured ");
+                        log.println("Exception occurred ");
                         e.printStackTrace(log);
                         bResult = false;
                     }
@@ -143,11 +143,11 @@ public class _XContainerQuery extends Mu
             Object element = subSet.nextElement();
             
             } catch (com.sun.star.container.NoSuchElementException e){
-                log.println("Exception occured ");
+                log.println("Exception occurred ");
                 e.printStackTrace(log);
                 bResult = false;
             } catch (com.sun.star.lang.WrappedTargetException e){
-                log.println("Exception occured ");
+                log.println("Exception occurred ");
                 e.printStackTrace(log);
                 bResult = false;
             }

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/container/_XContentEnumerationAccess.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/container/_XContentEnumerationAccess.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/container/_XContentEnumerationAccess.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/container/_XContentEnumerationAccess.java Tue Apr 29 19:13:51 2014
@@ -52,7 +52,7 @@ public class _XContentEnumerationAccess 
             serviceNames = oObj.getAvailableServiceNames();
             bResult = serviceNames != null ;
         } catch (Exception e) {
-            log.println("Exception occured. " + e);
+            log.println("Exception occurred. " + e);
             bResult = false;
         }
         tRes.tested("getAvailableServiceNames()", bResult);

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/container/_XEnumeration.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/container/_XEnumeration.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/container/_XEnumeration.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/container/_XEnumeration.java Tue Apr 29 19:13:51 2014
@@ -56,7 +56,7 @@ public class _XEnumeration extends Multi
     * Retrieves relation and sets oObj to a separate enumeration
     * created. Retrieves all elements from enumeration.<p>
     * Has <b> OK </b> status if all elements successfully retrieved
-    * and exceptions occured.
+    * and exceptions occurred.
     */
     public void _hasMoreElements() {
         boolean result = true;

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/container/_XIndexAccess.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/container/_XIndexAccess.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/container/_XIndexAccess.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/container/_XIndexAccess.java Tue Apr 29 19:13:51 2014
@@ -64,7 +64,7 @@ public class _XIndexAccess extends Multi
 
     /**
     * This method tests the IndexAccess from the first element,
-    * the middle element and the last element. Finaly it test
+    * the middle element and the last element. Finally it test
     * Exceptions which throws by a not available index. <p>
     * Has <b> OK </b> status if first, middle and last elements
     * successfully returned and has non null value; and if on

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/container/_XIndexContainer.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/container/_XIndexContainer.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/container/_XIndexContainer.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/container/_XIndexContainer.java Tue Apr 29 19:13:51 2014
@@ -76,7 +76,7 @@ public class _XIndexContainer extends Mu
     /**
     * First tries to insert proper object. Second tries to insert
     * null value. For each test thread different objects are inserted
-    * on different indexes. For exmaple for the first started test index
+    * on different indexes. For example for the first started test index
     * is 0 and object is get from relation 'INCTANCE1', and so on. <p>
     * Has <b>OK</b> status if in the first case <code>getByIndex</code>
     * method returns non null value and in the second <code>

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/container/_XNameReplace.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/container/_XNameReplace.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/container/_XNameReplace.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/container/_XNameReplace.java Tue Apr 29 19:13:51 2014
@@ -110,7 +110,7 @@ public class _XNameReplace extends Multi
             log.println("ObjRelation(\"INSTANCE" + Index +"\") Object n.a.");
         }
 
-        log.println("getting the existant object's name");
+        log.println("getting the existent object's name");
         XNameAccess oNameAccess = (XNameAccess)UnoRuntime.queryInterface(
                                                        XNameAccess.class, oObj);
         oNames = oNameAccess.getElementNames();

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/datatransfer/_XMimeContentTypeFactory.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/datatransfer/_XMimeContentTypeFactory.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/datatransfer/_XMimeContentTypeFactory.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/datatransfer/_XMimeContentTypeFactory.java Tue Apr 29 19:13:51 2014
@@ -70,7 +70,7 @@ public class _XMimeContentTypeFactory ex
                 result = false ;
             }
         } catch (com.sun.star.lang.IllegalArgumentException e) {
-            log.println("Exception occured : " ) ;
+            log.println("Exception occurred : " ) ;
             e.printStackTrace(log) ;
             result = false ;
         }

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/datatransfer/clipboard/_XClipboardEx.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/datatransfer/clipboard/_XClipboardEx.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/datatransfer/clipboard/_XClipboardEx.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/datatransfer/clipboard/_XClipboardEx.java Tue Apr 29 19:13:51 2014
@@ -42,7 +42,7 @@ public class _XClipboardEx extends Multi
 
     /**
     * Just calls the method. <p>
-    * Has <b> OK </b> status if no runtime exceptions occured.
+    * Has <b> OK </b> status if no runtime exceptions occurred.
     */
     public void _getRenderingCapabilities() {
         byte caps = oObj.getRenderingCapabilities();

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/datatransfer/clipboard/_XFlushableClipboard.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/datatransfer/clipboard/_XFlushableClipboard.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/datatransfer/clipboard/_XFlushableClipboard.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/datatransfer/clipboard/_XFlushableClipboard.java Tue Apr 29 19:13:51 2014
@@ -42,7 +42,7 @@ public class _XFlushableClipboard extend
 
     /**
     * Just calls the method. <p>
-    * Has <b> OK </b> status if no runtime exceptions occured.
+    * Has <b> OK </b> status if no runtime exceptions occurred.
     */
     public void _flushClipboard() {
         oObj.flushClipboard();

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/document/_LinkTarget.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/document/_LinkTarget.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/document/_LinkTarget.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/document/_LinkTarget.java Tue Apr 29 19:13:51 2014
@@ -59,7 +59,7 @@ public class _LinkTarget extends MultiPr
             tRes.tested("LinkDisplayName",LDN!=null);
         }
         catch (Exception ex) {
-            log.println("Exception occured during LinkDisplayName");
+            log.println("Exception occurred during LinkDisplayName");
             ex.printStackTrace(log);
             tRes.tested("LinkDisplayName",false);
         }

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/document/_XActionLockable.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/document/_XActionLockable.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/document/_XActionLockable.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/document/_XActionLockable.java Tue Apr 29 19:13:51 2014
@@ -46,7 +46,7 @@ public class _XActionLockable extends Mu
     /**
      * Method addActionLock called first and then
      * checked value returned by isActionLocked().<p>
-     * Has <b> OK </b> status if no runtime exceptions occured
+     * Has <b> OK </b> status if no runtime exceptions occurred
      * and returned value is true.
      */
     public void _isActionLocked() {
@@ -58,7 +58,7 @@ public class _XActionLockable extends Mu
 
     /**
     * Just calls the method. <p>
-    * Has <b> OK </b> status if no runtime exceptions occured
+    * Has <b> OK </b> status if no runtime exceptions occurred
     */
     public void _addActionLock() {
         requiredMethod("resetActionLocks()");
@@ -68,7 +68,7 @@ public class _XActionLockable extends Mu
 
     /**
     * Calls the method and check value returned by isActionLocked(). <p>
-    * Has <b> OK </b> status if no runtime exceptions occured
+    * Has <b> OK </b> status if no runtime exceptions occurred
     * and returned value is false.
     */
     public void _removeActionLock() {
@@ -80,7 +80,7 @@ public class _XActionLockable extends Mu
 
     /**
     * Calls the method with specific value. <p>
-    * Has <b> OK </b> status if no runtime exceptions occured
+    * Has <b> OK </b> status if no runtime exceptions occurred
     */
     public void _setActionLocks() {
         oObj.setActionLocks( nLock );

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/document/_XDocumentInsertable.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/document/_XDocumentInsertable.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/document/_XDocumentInsertable.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/document/_XDocumentInsertable.java Tue Apr 29 19:13:51 2014
@@ -126,7 +126,7 @@ public class _XDocumentInsertable extend
     /**
     * Tries to insert document from URL specified by relation or
     * from default URL. If no relation was passed, text range is
-    * checked for existance of loaded document content. In case
+    * checked for existence of loaded document content. In case
     * if relation was found, then its <code>isInserted</code>
     * method is used to check insertion.<p>
     * A Second test uses an invalid URL and checks for correct exceptions.
@@ -155,12 +155,12 @@ public class _XDocumentInsertable extend
             }
 
         } catch (com.sun.star.lang.IllegalArgumentException ex) {
-            log.println("Exception occured while testing "+
+            log.println("Exception occurred while testing "+
                 "insertDocumentFromURL()");
             ex.printStackTrace(log);
             result = false ;
         } catch (com.sun.star.io.IOException ex) {
-            log.println("Exception occured while testing "+
+            log.println("Exception occurred while testing "+
                 "insertDocumentFromURL()");
             ex.printStackTrace(log);
             result = false ;

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/document/_XExporter.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/document/_XExporter.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/document/_XExporter.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/document/_XExporter.java Tue Apr 29 19:13:51 2014
@@ -63,7 +63,7 @@ public class _XExporter extends MultiMet
 
     /**
     * Just calls the method. <p>
-    * Has <b> OK </b> status if no runtime exceptions occured.
+    * Has <b> OK </b> status if no runtime exceptions occurred.
         * Usually this interface is supported both with <code>XFilter</code>
         * where source document setting is checked.
     */

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/document/_XFilter.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/document/_XFilter.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/document/_XFilter.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/document/_XFilter.java Tue Apr 29 19:13:51 2014
@@ -50,7 +50,7 @@ import com.sun.star.uno.UnoRuntime;
 *  <li> <code>'XFilter.Checker'</code> <b>(optional)</b> (of type
 *   <code>ifc.document._XFilter.FilterChecker</code>) : implementation
 *   of interface must allow checking that document was exported successfully.
-*   If the relation doesn't exist then by default successfull filtering
+*   If the relation doesn't exist then by default successful filtering
 *   assumed.
 *  </li>
 * <ul> <p>
@@ -106,7 +106,7 @@ public class _XFilter extends MultiMetho
 
 	/**
 	* Just calls the method. <p>
-	* Has <b> OK </b> status if no runtime exceptions occured
+	* Has <b> OK </b> status if no runtime exceptions occurred
 	*/
 	public void _filter() {
         if (dummy) {
@@ -127,7 +127,7 @@ public class _XFilter extends MultiMetho
 
 	/**
 	* Just calls the method. <p>
-	* Has <b> OK </b> status if no runtime exceptions occured
+	* Has <b> OK </b> status if no runtime exceptions occurred
 	*/
 	public void _cancel() {
         if (dummy) {

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/document/_XImporter.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/document/_XImporter.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/document/_XImporter.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/document/_XImporter.java Tue Apr 29 19:13:51 2014
@@ -48,7 +48,7 @@ public class _XImporter extends MultiMet
 
     /**
     * Retrieves relation and sets target document. <p>
-    * Has <b> OK </b> status if no runtime exceptions occured,
+    * Has <b> OK </b> status if no runtime exceptions occurred,
     * really this method tested when the whole import result
     * checked.
     */

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/document/_XStandaloneDocumentInfo.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/document/_XStandaloneDocumentInfo.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/document/_XStandaloneDocumentInfo.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/document/_XStandaloneDocumentInfo.java Tue Apr 29 19:13:51 2014
@@ -60,7 +60,7 @@ public class _XStandaloneDocumentInfo ex
     String newProp = null;
     /**
     * Sets new value of the property 'Author' and calls the method. <p>
-    * Has <b> OK </b> status if no exception occured.
+    * Has <b> OK </b> status if no exception occurred.
     */
     public void _storeIntoURL() {
         try {
@@ -95,7 +95,7 @@ public class _XStandaloneDocumentInfo ex
 
     /**
     * Calls the method and checks value of the property 'Author'. <p>
-    * Has <b> OK </b> status if no exception occured and value of the property
+    * Has <b> OK </b> status if no exception occurred and value of the property
     * 'Author' is equal to value that was set in the method
     * <code>storeIntoURL</code>.
     */
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/beans/_XPropertySet.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/beans/_XPropertySet.java Tue Apr 29 19:13:51 2014
@@ -175,19 +175,19 @@ public class _XPropertySet extends Multi
                     oObj.setPropertyValue(propertyName,
                         ValueChanger.changePValue(gValue));
                 } catch (com.sun.star.beans.PropertyVetoException e) {
-                    log.println("Exception occured while trying to change "+
+                    log.println("Exception occurred while trying to change "+
                         "property '"+ propertyName+"'");
                     e.printStackTrace(log);
                 } catch (com.sun.star.lang.IllegalArgumentException e) {
-                    log.println("Exception occured while trying to change "+
+                    log.println("Exception occurred while trying to change "+
                         "property '"+ propertyName+"'");
                     e.printStackTrace(log);
                 } catch (com.sun.star.beans.UnknownPropertyException e) {
-                    log.println("Exception occured while trying to change "+
+                    log.println("Exception occurred while trying to change "+
                         "property '"+ propertyName+"'");
                     e.printStackTrace(log);
                 } catch (com.sun.star.lang.WrappedTargetException e) {
-                    log.println("Exception occured while trying to change "+
+                    log.println("Exception occurred while trying to change "+
                         "property '"+ propertyName+"'");
                     e.printStackTrace(log);
                 } // end of try-catch
@@ -235,19 +235,19 @@ public class _XPropertySet extends Multi
                     oObj.setPropertyValue(propertyName,
                         ValueChanger.changePValue(gValue));
                 } catch (com.sun.star.beans.PropertyVetoException e) {
-                    log.println("Exception occured while trying to change "+
+                    log.println("Exception occurred while trying to change "+
                         "property '"+ propertyName+"'");
                     e.printStackTrace(log);
                 } catch (com.sun.star.lang.IllegalArgumentException e) {
-                    log.println("Exception occured while trying to change "+
+                    log.println("Exception occurred while trying to change "+
                         "property '"+ propertyName+"'");
                     e.printStackTrace(log);
                 } catch (com.sun.star.beans.UnknownPropertyException e) {
-                    log.println("Exception occured while trying to change "+
+                    log.println("Exception occurred while trying to change "+
                         "property '"+ propertyName+"'");
                     e.printStackTrace(log);
                 } catch (com.sun.star.lang.WrappedTargetException e) {
-                    log.println("Exception occured while trying to change "+
+                    log.println("Exception occurred while trying to change "+
                         "property '"+ propertyName+"'");
                     e.printStackTrace(log);
                 } // end of try-catch
@@ -299,19 +299,19 @@ public class _XPropertySet extends Multi
                     oObj.setPropertyValue(propertyName, sValue);
                     sValue = oObj.getPropertyValue(propertyName);
                 } catch (com.sun.star.beans.PropertyVetoException e) {
-                    log.println("Exception occured while trying to change "+
+                    log.println("Exception occurred while trying to change "+
                         "property '"+ propertyName+"'");
                     e.printStackTrace(log);
                 } catch (com.sun.star.lang.IllegalArgumentException e) {
-                    log.println("Exception occured while trying to change "+
+                    log.println("Exception occurred while trying to change "+
                         "property '"+ propertyName+"'");
                     e.printStackTrace(log);
                 } catch (com.sun.star.beans.UnknownPropertyException e) {
-                    log.println("Exception occured while trying to change "+
+                    log.println("Exception occurred while trying to change "+
                         "property '"+ propertyName+"'");
                     e.printStackTrace(log);
                 } catch (com.sun.star.lang.WrappedTargetException e) {
-                    log.println("Exception occured while trying to change "+
+                    log.println("Exception occurred while trying to change "+
                         "property '"+ propertyName+"'");
                     e.printStackTrace(log);
                 } // end of try-catch
@@ -330,7 +330,7 @@ public class _XPropertySet extends Multi
 
     /**
     * Tests <code>getPropertyValue</code> method for the given property.
     * Returns true if no exceptions occured
     */
     private boolean getSinglePropertyValue( String propertyName )
     {
@@ -339,11 +339,11 @@ public class _XPropertySet extends Multi
             oObj.getPropertyValue(propertyName);
             runOk = true;
         } catch (com.sun.star.beans.UnknownPropertyException e) {
-            log.println("Exception occured while trying to get property '"+
+            log.println("Exception occurred while trying to get property '"+
                  propertyName+"'");
             e.printStackTrace(log);
         } catch (com.sun.star.lang.WrappedTargetException e) {
-            log.println("Exception occured while trying to get property '"+
+            log.println("Exception occurred while trying to get property '"+
                 propertyName+"'");
             e.printStackTrace(log);
         }
@@ -423,7 +423,7 @@ public class _XPropertySet extends Multi
                 try {
                     oObj.removePropertyChangeListener(propertyName,PClistener);
                 } catch (Exception e) {
-                    log.println("Exception occured while removing change listener from"+
+                    log.println("Exception occurred while removing change listener from"+
                         "property '"+ propertyName+"'");
                     e.printStackTrace(log);
                 }
@@ -440,19 +440,19 @@ public class _XPropertySet extends Multi
                     oObj.setPropertyValue(propertyName,
                         ValueChanger.changePValue(gValue));
                 } catch (com.sun.star.beans.PropertyVetoException e) {
-                    log.println("Exception occured while trying to change "+
+                    log.println("Exception occurred while trying to change "+
                         "property '"+ propertyName+"'");
                     e.printStackTrace(log);
                 } catch (com.sun.star.lang.IllegalArgumentException e) {
-                    log.println("Exception occured while trying to change "+
+                    log.println("Exception occurred while trying to change "+
                         "property '"+ propertyName+"'");
                     e.printStackTrace(log);
                 } catch (com.sun.star.beans.UnknownPropertyException e) {
-                    log.println("Exception occured while trying to change "+
+                    log.println("Exception occurred while trying to change "+
                         "property '"+ propertyName+"'");
                     e.printStackTrace(log);
                 } catch (com.sun.star.lang.WrappedTargetException e) {
-                    log.println("Exception occured while trying to change "+
+                    log.println("Exception occurred while trying to change "+
                         "property '"+ propertyName+"'");
                     e.printStackTrace(log);
                 } // end of try-catch
@@ -499,7 +499,7 @@ public class _XPropertySet extends Multi
                 try {
                     oObj.removeVetoableChangeListener(propertyName,VClistener);
                 } catch (Exception e) {
-                    log.println("Exception occured while removing veto listener from"+
+                    log.println("Exception occurred while removing veto listener from"+
                         "property '"+ propertyName+"'");
                     e.printStackTrace(log);
                 }
@@ -516,19 +516,19 @@ public class _XPropertySet extends Multi
                     oObj.setPropertyValue(propertyName,
                         ValueChanger.changePValue(gValue));
                 } catch (com.sun.star.beans.PropertyVetoException e) {
-                    log.println("Exception occured while trying to change "+
+                    log.println("Exception occurred while trying to change "+
                         "property '"+ propertyName+"'");
                     e.printStackTrace(log);
                 } catch (com.sun.star.lang.IllegalArgumentException e) {
-                    log.println("Exception occured while trying to change "+
+                    log.println("Exception occurred while trying to change "+
                         "property '"+ propertyName+"'");
                     e.printStackTrace(log);
                 } catch (com.sun.star.beans.UnknownPropertyException e) {
-                    log.println("Exception occured while trying to change "+
+                    log.println("Exception occurred while trying to change "+
                         "property '"+ propertyName+"'");
                     e.printStackTrace(log);
                 } catch (com.sun.star.lang.WrappedTargetException e) {
-                    log.println("Exception occured while trying to change "+
+                    log.println("Exception occurred while trying to change "+
                         "property '"+ propertyName+"'");
                     e.printStackTrace(log);
                 } // end of try-catch
@@ -330,7 +330,7 @@ public class _XPropertySet extends Multi
     /**
     * Tests <code>getPropertyValue</code> method for the given property.
-    * Returns true if no exceptions occured
+    * Returns true if no exceptions occurred
     */
     private boolean getSinglePropertyValue( String propertyName )

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/beans/_XPropertyState.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/beans/_XPropertyState.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/connection/_XAcceptor.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/connection/_XAcceptor.java Tue Apr 29 19:13:51 2014
@@ -53,12 +53,12 @@ public class _XAcceptor extends MultiMet
 
     /**
     * Calls <code>accept()</code> method in a separate thread.
     * Then stores exception thrown by call if it occured, or
     * return value.
     */
     protected class AcceptorThread extends Thread {
         /**
         * If exception occured during method call it is
         * stored in this field.
         */
         public Exception ex = null ;
@@ -179,7 +179,7 @@ public class _XAcceptor extends MultiMet
                         acception.acceptedCall.getDescription()) ;
             } else {
                 if (acception.ex != null) {
-                    log.println("Exception occured in accept() thread :") ;
+                    log.println("Exception occurred in accept() thread :") ;
                     acception.ex.printStackTrace(log) ;
                 }
 
@@ -299,7 +299,7 @@ public class _XAcceptor extends MultiMet
 
         } else {
             if (acception.ex != null) {
-                log.println("Exception occured in accept() thread :") ;
+                log.println("Exception occurred in accept() thread :") ;
                 acception.ex.printStackTrace(log) ;
                 result = false ;
             } else {
@@ -53,12 +53,12 @@ public class _XAcceptor extends MultiMet
     /**
     * Calls <code>accept()</code> method in a separate thread.
-    * Then stores exception thrown by call if it occured, or
+    * Then stores exception thrown by call if it occurred, or
     * return value.
     */
@@ -53,12 +53,12 @@ public class _XAcceptor extends MultiMet
     protected class AcceptorThread extends Thread {
         /**
-        * If exception occured during method call it is
+        * If exception occurred during method call it is
         * stored in this field.
         */

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/connection/_XConnector.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/connection/_XConnector.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/connection/_XConnector.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/connection/_XConnector.java Tue Apr 29 19:13:51 2014
@@ -49,7 +49,7 @@ public class _XConnector extends MultiMe
 
     /**
     * Calls <code>accept()</code> method in a separate thread.
     * Then stores exception thrown by call if it occured, or
     * return value.
     */
     protected class AcceptorThread extends Thread {
@@ -58,7 +58,7 @@ public class _XConnector extends MultiMe
          */
         private XAcceptor acc = null ;
         /**
         * If exception occured during method call it is
         * stored in this field.
         */
         public Exception ex = null ;
@@ -163,7 +163,7 @@ public class _XConnector extends MultiMe
                         acceptorThread.acceptedCall.getDescription()) ;
             } else {
                 if (acceptorThread.ex != null) {
-                    log.println("Exception occured in accept() thread :") ;
+                    log.println("Exception occurred in accept() thread :") ;
                     acceptorThread.ex.printStackTrace(log) ;
                 }
 
@@ -49,7 +49,7 @@ public class _XConnector extends MultiMe
     /**
     * Calls <code>accept()</code> method in a separate thread.
-    * Then stores exception thrown by call if it occured, or
+    * Then stores exception thrown by call if it occurred, or
     * return value.
     */
@@ -58,7 +58,7 @@ public class _XConnector extends MultiMe
         private XAcceptor acc = null ;
         /**
-        * If exception occured during method call it is
+        * If exception occurred during method call it is
         * stored in this field.
         */

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/container/_XChild.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/container/_XChild.java?rev=1591061&r1=1591060&r2=1591061&view=diff
==============================================================================